rm(list=ls(all=TRUE))  # clear all variables

library(aod)

# Greg Francis (gfrancis@purdue.edu)  December 2013

# Experiment 6 had one measure with three conditions (2 controls)

# define properties of experiment
n1 = 42
n2 =43
n3 = 46

f1 = 29
f2 = 20
f3 = 12

alpha = 0.05

# Two-two, Combined, Two-Three
proportions = c(f1/n1, f2/n2, f3/n3)

# repeat experiments to estimate power
numExperiments =10000

RejectNull <- 0*c(1: numExperiments)


for(experimentNum in c(1: numExperiments)){


#cat(experimentNum, "\n")

    x1 =  runif( n=n1, min=0, max=1) 
	y1 =  runif( n=n2 , min=0, max=1) 	
    z1 =  runif( n=n3, min=0, max=1) 
	
	# convert to 0-1 responses
	TwoTwo = ifelse(x1<= proportions[1], 1, 0)
	Combined = ifelse(y1<= proportions[2], 1, 0)
	TwoThree = ifelse(z1<= proportions[3], 1, 0)
	
	# just to test out data from paper (it matches)	
	if(1==0){
	TwoTwo[1:f1] = 1
	TwoTwo[(f1+1):n1] = 0	
	Combined[1:f2] = 1
	Combined[(f2+1):n2] = 0	
	TwoThree[1:f3] = 1
	TwoThree[(f3+1):n3] = 0
	}
	# Write to data file
	
	sink("tempData.csv")
	
	cat("Categorized,  DoFullTask\n")
		
	for(i in c(1:n1)){
		cat("1, ", TwoTwo[i],"\n")
	}
	for(i in c(1:n2)){
		cat("2, ", Combined[i],"\n")
	}
	for(i in c(1:n3)){
		cat("3, ", TwoThree[i],"\n")
	}

	
	sink()
	
	mydata <-read.csv("tempData.csv")
	
	mydata$Categorized<-factor(mydata $Categorized)
	
	mylogit <- glm(DoFullTask ~ Categorized, data = mydata, family = "binomial")


	p2<-summary(mylogit)$coefficients[2,4]
	p3<-summary(mylogit)$coefficients[3,4]

	
			if (p2<=alpha && p3<=alpha && mean(TwoTwo)> mean(Combined) && mean(TwoTwo)> mean(TwoThree))	{
				RejectNull[experimentNum] = 1
				}
}  #End current experiment

# output statistics
propReject = sum(RejectNull)/numExperiments


cat("Proportion reject =", propReject, "\n")
